@@ -50,7 +50,7 @@ class CustomTestFetchTransport(HTTPFetchTransport):
     def __init__(self, config, keychain, **kwargs):
         super(CustomTestFetchTransport, self).__init__(config, keychain, **kwargs)
         if self.keychain:
-            logging.debug("Got propagated keychain: %s" % json.dumps(self.keychain))
+            logger.debug("Got propagated keychain: %s" % json.dumps(self.keychain))
 
     def fetch(self, url, output_path, **kwargs):
         return super(CustomTestFetchTransport, self).fetch(url, output_path, **kwargs)
@@ -72,6 +72,7 @@ class TestRemoteAPI(BaseTest):
         self.stream = StringIO()
         self.handler = logging.StreamHandler(self.stream)
         logger.addHandler(self.handler)
+        logger.setLevel(logging.DEBUG)
 
     def tearDown(self):
         self.stream.close()
